@@ -13,7 +13,10 @@ class Recipe(object):
     # mimetype-registry is need spaces for identation.
     if "mimetype-registry" in options:
       options["mimetype-registry"] = options["mimetype-registry"].replace("\n",
-                                                                       "\n ")
+                                                                       "\n  ")
+    if "handler-mapping" in options:
+      options["handler-mapping"] = options["handler-mapping"].replace("\n",
+                                                                      "\n  ")
     self.conf_template = z3c_template.Recipe(buildout, name, options)
     options['input'] = path.join(path.abspath(path.dirname(__file__)), 
                                   "cloudoooctl.in")
